#ifndef __GUI_CHANNELS_H
#define __GUI_CHANNELS_H

#define CHANNEL_GUI(a) ((GUI_CHANNEL_REC *) ((a)->gui_data))

/*typedef struct
{
}
GUI_CHANNEL_REC;*/

void gui_channels_init(void);
void gui_channels_deinit(void);

#endif
